@@ -414,6 +414,9 @@ class Browser(QMainWindow):
         c(self.pgUpCut, SIGNAL("activated()"), self.onFirstCard)
         self.pgDownCut = QShortcut(QKeySequence("Shift+End"), self)
         c(self.pgDownCut, SIGNAL("activated()"), self.onLastCard)
+        # add note
+        self.addCut = QShortcut(QKeySequence("Ctrl+E"), self)
+        c(self.addCut, SIGNAL("activated()"), self.mw.onAddCard)
         # card info
         self.infoCut = QShortcut(QKeySequence("Ctrl+Shift+I"), self)
         c(self.infoCut, SIGNAL("activated()"), self.showCardInfo)
@@ -427,6 +430,9 @@ class Browser(QMainWindow):
         c(self.tagCut2, SIGNAL("activated()"), self.deleteTags)
         self.tagCut3 = QShortcut(QKeySequence("Ctrl+K"), self)
         c(self.tagCut3, SIGNAL("activated()"), self.onMark)
+        # suspending
+        self.susCut1 = QShortcut(QKeySequence("Ctrl+J"), self)
+        c(self.susCut1, SIGNAL("activated()"), self.onSuspend)
         # deletion
         self.delCut1 = QShortcut(QKeySequence("Delete"), self)
         self.delCut1.setAutoRepeat(False)
@@ -1709,12 +1715,14 @@ class BrowserToolbar(Toolbar):
 <a class=hitem title="%s" href="%s"><img style="padding: 1px;" valign=bottom src="qrc:/icons/%s.png"> %s</a>'''
             return fmt % (tooltip or title, link, icon, title)
         right = "<div>"
-        right += borderImg("add", "add16", False, _("Add"))
+        right += borderImg("add", "add16", False, _("Add"),
+                       shortcut(_("Add Note (Ctrl+E)")))
         right += borderImg("info", "info", False, _("Info"),
                        shortcut(_("Card Info (Ctrl+Shift+I)")))
         right += borderImg("mark", "star16", mark, _("Mark"),
                        shortcut(_("Mark Note (Ctrl+K)")))
-        right += borderImg("pause", "pause16", pause, _("Suspend"))
+        right += borderImg("pause", "pause16", pause, _("Suspend"),
+                       shortcut(_("Suspend Card (Ctrl+J)")))
         right += borderImg("setDeck", "deck16", False, _("Change Deck"),
                            shortcut(_("Move To Deck (Ctrl+D)")))
         right += borderImg("addtag", "addtag16", False, _("Add Tags"),
